Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(811)

Unified Diff: third_party/WebKit/Source/modules/webdatabase/DatabaseContext.h

Issue 2583093002: Reduce SuspendableObjects (Closed)
Patch Set: Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/webdatabase/DatabaseContext.h
diff --git a/third_party/WebKit/Source/modules/webdatabase/DatabaseContext.h b/third_party/WebKit/Source/modules/webdatabase/DatabaseContext.h
index 6f84ff7c34e6d0dc1074dabe7661973367dadcf4..a5140551114f54facbba6c8e0fb60f0db913d944 100644
--- a/third_party/WebKit/Source/modules/webdatabase/DatabaseContext.h
+++ b/third_party/WebKit/Source/modules/webdatabase/DatabaseContext.h
@@ -28,7 +28,7 @@
#ifndef DatabaseContext_h
#define DatabaseContext_h
-#include "core/dom/SuspendableObject.h"
+#include "core/dom/ContextLifecycleObserver.h"
#include "platform/heap/Handle.h"
namespace blink {
@@ -39,7 +39,7 @@ class ExecutionContext;
class SecurityOrigin;
class DatabaseContext final : public GarbageCollectedFinalized<DatabaseContext>,
- public SuspendableObject {
+ public ContextLifecycleObserver {
USING_GARBAGE_COLLECTED_MIXIN(DatabaseContext);
public:
@@ -47,10 +47,10 @@ class DatabaseContext final : public GarbageCollectedFinalized<DatabaseContext>,
static DatabaseContext* create(ExecutionContext*);
- ~DatabaseContext() override;
+ ~DatabaseContext();
DECLARE_VIRTUAL_TRACE();
// For life-cycle management (inherited from SuspendableObject):
void contextDestroyed() override;
DatabaseContext* backend();
@@ -47,10 +47,10 @@ class DatabaseContext final : public GarbageCollectedFinalized<DatabaseContext>,
DECLARE_VIRTUAL_TRACE();
- // For life-cycle management (inherited from SuspendableObject):
+ // For life-cycle management (inherited from ContextLifecycleObserver):
void contextDestroyed() override;
DatabaseContext* backend();

Powered by Google App Engine
This is Rietveld 408576698